@@ -3,9 +3,9 @@ Created on 2022-11-24
 
 @author: wf
 '''
-from tests.basetest import Basetest
 import os
 from wikibot.wikiuser import WikiUser
+from tests.basetest import Basetest
 
 class BaseMediawikiTest(Basetest):
     """
@@ -26,7 +26,10 @@ class BaseMediawikiTest(Basetest):
             if wikiId == "wiki":
                 wikiDict = {"wikiId": wikiId, "email": "noreply@nouser.com", "url": "https://wiki.bitplan.com",
                             "scriptPath": "/", "version": "MediaWiki 1.35.5"}
-        
+            if wikiId == "ceur-ws":
+                wikiDict = {"wikiId": wikiId, "email": "noreply@nouser.com",
+                            "url": "https://ceur-ws.bitplan.com", "scriptPath": "/",
+                            "version": "MediaWiki 1.35.5"}
             if wikiDict is None:
                 raise Exception(f"wikiId {wikiId} is not known")
             else:
@@ -39,4 +42,4 @@ class BaseMediawikiTest(Basetest):
                         print(f"saved wikiUser for {wikiId}")
         else:
             wikiUser = WikiUser.ofWikiId(wikiId, lenient=True)
-        return wikiUser
+        return wikiUser
\ No newline at end of file
